---
layout: post
title: CONOPS (Concept of Operations)
author: jabenninghoff
comments: true
---
I recently came across a posting on [Design Docs at Google](https://www.industrialempathy.com/posts/design-docs-at-google/). I was struck by the similarities between the design document, as described in the article, and a [Concept of Operations (CONOPS)](https://en.wikipedia.org/wiki/Concept_of_operations). Traditionally, CONOPS are primarily used by the military, for very large and costly projects, such as the design of a new [Coast Guard Cutter](/assets/CONOPS_RFPRelease.pdf), created prior to official design documentation, and [mainly serve to satisfy project requirements](https://apps.dtic.mil/sti/tr/pdf/ADA530139.pdf), and is not something you'd expect a modern software organization like Google to use.

In my own work, I've come to believe that a shared mental model of the application or service the team is building is essential for reliability and resilience, and there is research that suggests [an agile CONOPS can help develop a shared mental model](https://onlinelibrary.wiley.com/doi/abs/10.1002/sys.20190) amongst stakeholders, by using visualization, models, and system thinking. My own brief experiment with CONOPS found that creating a visual diagram is most valuable, the formal CONOPS outline, defined in [IEEE standard 1362](https://ieeexplore.ieee.org/document/761853), was less useful.

What's interesting about the Google Design Doc is that it includes important elements of the CONOPS. The article identifies the following functions of the design document (**emphasis** mine):

> - Early identification of design issues when making changes is still cheap.
> - **Achieving consensus around a design in the organization.**
> - **Ensuring consideration of cross-cutting concerns.**
> - **Scaling knowledge of senior engineers into the organization.**
> - **Form the basis of an organizational memory around design decisions.**
> - Acts as a summary artifact in the technical portfolio of the software designer(s).

It's notable that four of the six functions all relate to development of a shared mental model of the system being built - across the engineering organization, with security & privacy, senior engineers, and for posterity. Additionally, I argue that many of the features described would also be found in a good CONOPS: Goals and Non-Goals, visual diagrams, and existing constraints. Unsurprisingly, the post also recommends making the document only as long as needed, avoid creating an 'implementation manual', and iterate.

I'd agree with all of that, and would also suggest one additional lesson from well written CONOPS: adding operational scenarios, as included in the [CPC CONOPS](/assets/CONOPS_RFPRelease.pdf) mentioned earlier, can be an effective tool for helping people understand what's being proposed, and how the designers envision it being used. Having specific narratives helps 'make it real', and makes implicit assumptions more explicit.

Bottom Line: whether you call it a CONOPS or a design document, creating a high-level description of what you're planning to build, without getting into the weeds, is an underutilized but effective way to build better software systems. Focus on visualization and creating a common mental model for the organization (including our future selves), iterate, and consider using scenarios to help build understanding.
